@@ -103,9 +103,9 @@ typedef enum
 /*
  * functions defined in oracle_utils.c
  */
-extern oracleSession *oracleGetSession(const char *connectstring, char *user, char *password, const char *nls_lang, const char *tablename);
-extern void oracleReleaseSession(oracleSession *session, struct oraTable *oraTable, int close);
-extern void oracleCloseStatement(oracleSession *session, const struct oraTable *oraTable);
+extern oracleSession *oracleGetSession(const char *connectstring, char *user, char *password, const char *nls_lang, const char *tablename, int transaction);
+extern void oracleReleaseSession(oracleSession *session, int close, int error);
+extern void oracleCloseStatement(oracleSession *session);
 extern void oracleCloseConnections(void);
 extern void oracleShutdown(void);
 extern int oracleIsStatementOpen(oracleSession *session);
@@ -115,10 +115,13 @@ extern void oracleExplain(oracleSession *session, const char *query, int *nrows,
 extern int oracleExecuteQuery(oracleSession *session, const char *query, const struct oraTable *oraTable, struct paramDesc *paramList);
 extern int oracleFetchNext(oracleSession *session, struct oraTable *oraTable);
 extern void oracleGetLob(oracleSession *session, struct oraTable *oraTable, void *locptr, oraType type, char **value, long *value_len);
+extern void oracleCleanupTransaction(void *arg);
 
 /*
  * functions defined in oracle_fdw.c
  */
+extern void oracleRegisterCallback(void *arg);
+extern void oracleUnregisterCallback(void *arg);
 extern void *oracleAlloc(size_t size);
 extern void *oracleRealloc(void *p, size_t size);
 extern void oracleFree(void *p);
@@ -126,3 +129,4 @@ extern void oracleError_d(oraError sqlstate, const char *message, const char *de
 extern void oracleError_sd(oraError sqlstate, const char *message, const char *arg, const char *detail);
 extern void oracleError_i(oraError sqlstate, const char *message, int arg);
 extern void oracleError(oraError sqlstate, const char *message);
+extern void oracleDebug2(const char *message);
